package CollectorModule;

import netscape.WAI.Naming;

class CollectorServer
{ 
  static public void main(String[] args)
  { 
    CollectorOptions    opts = new CollectorOptions(args);
    CollectorData sharedData = new CollectorData(opts.maxStn);
    
    System.out.println("Collector is initializing as \"" +
                        opts.cname + "\"");
    try
    { // Initialize the ORB.
      org.omg.CORBA.ORB orb = org.omg.CORBA.ORB.init();

      // Initialize the BOA.
      org.omg.CORBA.BOA boa = orb.BOA_init();

      // Create the Count object.
      CollectorImpl collector = new CollectorImpl(opts.cname, sharedData);
      // Export to the ORB newly created object.
      boa.obj_is_ready(collector);

      try 
      {
          String host = java.net.InetAddress.getLocalHost().getHostName();
          Naming.register("http://" + host + "/iiop_objects/" + opts.cname, collector);
   	} 
   	catch (Exception e) 
   	{ e.printStackTrace(); }
	  

      StationPollThread spt = new StationPollThread(opts.updInt, sharedData);
      spt.start();

      System.out.println("Collector is ready for service");
      // Ready to service requests.
      boa.impl_is_ready();
    }
    catch(org.omg.CORBA.SystemException e) {
      System.err.println(e);
    }
    
  }
};


class StationPollThread extends Thread 
{
  private CollectorData sharedData;
  private int updInt;
  
  public StationPollThread(int updInt, CollectorData sharedData) {
    super();
    
    this.updInt = updInt;
    this.sharedData = sharedData;
  }

  public void run() {
    
    while (true) {
        StationModule.StationData[] results, resultsTmp;
        int resultsIndex = 0;
        
        
        synchronized (this.sharedData) {
            resultsTmp = new StationModule.StationData[this.sharedData.maxStations];
            if (this.sharedData.monitorRef != null) {
                StationInfo currStation;

                for (int index=0;index<this.sharedData.maxStations;index++) {
                    currStation = this.sharedData.stations[index];
                    if ( currStation != null) {
                        try {
                            resultsTmp[index] = currStation.stationRef.getStatus();
                        } catch (java.lang.Exception e) {
                            System.out.println("Station \"" + 
                                               currStation.stationID +
                                               "\" died!");
                            this.sharedData.stations[index] = null;
                            this.sharedData.numStations--;
                        }

                    }
                }
                results = new StationModule.StationData[this.sharedData.numStations];
                for (int index=0; index<this.sharedData.maxStations; index++) {
                    if (resultsTmp[index] != null) {
                        results[resultsIndex++] = resultsTmp[index];
                    }
                }
                
                try {
                    this.sharedData.monitorRef.update(results);
                } catch (java.lang.Exception e) {
                    System.out.println("Monitor died!");
                    this.sharedData.monitorRef = null;
                }
            }              
        }
        try { this.sleep(updInt); } catch (java.lang.InterruptedException e) {}
    } 
  }
}
