package MonitorModule;

import java.awt.*;
import java.lang.*;
import amd.*;
import java.applet.Applet;
import netscape.WAI.Naming;


public class DisplayStationApplet extends Applet
{
      StationModule.StationData stationData;
      StationModule.Station station;
      String stName="";
      TextField nameField;
      TextField statusField;
      Label nameLabel;
      Label valueW[];
      Label valueE[];
      Panel gridRows[];
      AMDProgressBar progressBar;

      public void init()
      {
         try
         {
            // Initialize the ORB.
            org.omg.CORBA.ORB orb = org.omg.CORBA.ORB.init();

            // Initialize the BOA.
            org.omg.CORBA.BOA boa = orb.BOA_init();
	      }

         catch(org.omg.CORBA.SystemException e)
         {
            System.err.println(e);
            e.printStackTrace();
         }

         if (station == null) initStData();
         drawing();

      }


      public void initStData()
      {                    

         stationData = new StationModule.StationData();
         stationData.name = "[No Station]";
         stationData.id = "";
         stationData.description = "";
         stationData.numInitUnits = 0;
         stationData.numQueuedUnits = 0;
         stationData.numFinishedUnits = 0;
         stationData.percentComplete = (float)0.0;
         stationData.timePerUnit = (float)0.0;
         stationData.simTime = (float)0.0;
         stationData.simTimeFactor = (float)0.0;
         stationData.realStartTime = 0;
         stationData.etcCurrent = (float)0.0;
         stationData.etcRemaining = (float)0.0;
      }


      // Binds to the station Object using Web naming
      // Look for a file by the same name as the station in the  iiop_objects
      // directory in the Web server. The file contains the IOR for the 
      // station object.
      public boolean bindStation(String stName)
      {

         try
         {
    	      String host = getCodeBase().getHost();
            org.omg.CORBA.Object o = Naming.resolve("http://" + host + "/iiop_objects/" + stName);
            station = StationModule.StationHelper.narrow(o);
            System.out.println("Bound to " + stName);
         }
         catch(org.omg.CORBA.SystemException e)
         {
            System.err.println(e);
            e.printStackTrace();
            System.out.println("Couldn't find station " + stName);
            return false;
         }

         stationData = new StationModule.StationData();
         return true;
      }



      // Format the value received to just display one decimal place.
      // Returns it in a string.
      public String formatDouble(double toBeFormatted)
      {
         String stringResult;
         String endChar;
     
         stringResult = java.lang.String.valueOf((int)(java.lang.Math.floor(toBeFormatted * 10)));
         endChar = stringResult.substring(stringResult.length() - 1);
         if (stringResult.length() > 1)
            stringResult = stringResult.substring(0, stringResult.length() - 1);
         else
            stringResult = "0";
         stringResult = stringResult.concat(".");
         stringResult = stringResult.concat(endChar);
         return(stringResult);
      }


      // Display data from station object
      public void writeValues()
      {

         progressBar.setPercent((double)stationData.percentComplete / (double)100);

         nameLabel.setText(java.lang.String.valueOf(stationData.name));

         valueW[0].setText(java.lang.String.valueOf(stationData.description));
         //row 0 does not have east side
         valueW[1].setText(java.lang.String.valueOf(stationData.numInitUnits));
         valueE[1].setText(formatDouble(stationData.percentComplete) + " %");
         valueW[2].setText(java.lang.String.valueOf(stationData.numFinishedUnits));
         valueE[2].setText(java.lang.String.valueOf(stationData.numQueuedUnits));
         valueW[3].setText(java.lang.String.valueOf(formatDouble(stationData.simTime)));
         valueE[3].setText(java.lang.String.valueOf(formatDouble(stationData.etcRemaining)));
         valueW[4].setText(java.lang.String.valueOf(formatDouble(stationData.timePerUnit)));
         valueE[4].setText(java.lang.String.valueOf(formatDouble(stationData.etcCurrent)));

      }


      // Set gridLayout for station data
      public void writeLabels(int rowNum, String string1, String string2)
      {

         Panel cellW = new Panel();
         cellW.setLayout(new BorderLayout());
         cellW.add("West", new Label(string1));
         cellW.add("Center", valueW[rowNum] = new Label(""));
         gridRows[rowNum].add(cellW);

         Panel cellE = new Panel();
         cellE.setLayout(new BorderLayout());
         cellE.add("West", new Label(string2));
         cellE.add("Center", valueE[rowNum] = new Label(""));
         gridRows[rowNum].add(cellE);

      }


      // Draws applet using Layout managers
      public void drawing()
      {
         Panel p;
         Color white = new Color(255,255,255);

         int width = 500;
         int height = 250;
         resize(width, height);


         setBackground(white);
   
         Panel myPanel = new Panel();

         setLayout(new BorderLayout());

         myPanel.setLayout(new BorderLayout());
         add("Center",myPanel);
   
         // divides detail panel in North and Center
         Panel b2North = new Panel();
         Panel b2Center = new Panel();

         b2North.setLayout(new BorderLayout());
         b2Center.setLayout(new GridLayout(5,0));
         myPanel.add("North", b2North);
         myPanel.add("Center", b2Center);

         // configures b2North
         Panel b3North = new Panel();
         Panel b3Center = new Panel();

         b3North.setLayout(new BorderLayout());
         b3Center.setLayout(new FlowLayout());
         b2North.add("North", b3North);
         b2North.add("Center", b3Center);

         // add components (station name) to b3North
         // set Font for name
         Font font = new Font("TimesRoman", Font.BOLD, 24);
         setFont(font);
   
         nameLabel = new Label("",Label.CENTER);
         b3North.add("Center",nameLabel);
      
         // reset Font
         font = new Font("TimesRoman", Font.PLAIN, 14);
         setFont(font);

         // add components (Progress Bar) to b3Center
         b3Center.add(progressBar = new AMDProgressBar());
   	   progressBar.reshape(0, 0, 180, 20);
            try
	         { progressBar.setPercent((double)stationData.percentComplete / (double)100); }
	         catch (Exception e) 
	         { e.printStackTrace(); }


         // configures b2Center
         gridRows = new Panel[6];
         valueW = new Label[5];
         valueE = new Label[5];

         p = new Panel();
         p.setLayout(new GridLayout(0,1));
         gridRows[0] = p;
         b2Center.add(gridRows[0]);


         for (int i=1; i<6; i++)
         {

            p = new Panel();
            p.setLayout(new GridLayout(0,2));

            gridRows[i] = p;
            b2Center.add(gridRows[i]);
         }

         Panel r1 = new Panel();
         r1.setLayout(new BorderLayout());
         r1.add("West", new Label("Description:"));
         r1.add("Center", valueW[0] = new Label(""));
         gridRows[0].add(r1);

         writeLabels(1, "Initial units:", "Percent complete of current unit:");
         writeLabels(2, "Units finished:", "Units queued:");
         writeLabels(3, "Total simulation time:", "Time for completion of all units:");
         writeLabels(4, "Time per unit:", "Time for completion of current unit:");
         writeValues();

         Panel pEast = new Panel();
         Panel pWest = new Panel();
         Panel pSouth = new Panel();

         p.setLayout(new BorderLayout());

         pWest.setLayout(new FlowLayout());
         pEast.setLayout(new FlowLayout());
         pSouth.setLayout(new BorderLayout());
         p.add("West", pWest);
         p.add("East", pEast);
         p.add("South", pSouth);
         pWest.add(new Label("Enter Station Name"));
         pWest.add(nameField = new TextField("",10));
         pEast.add(new Button("Get Status"));
         add("South", p);

      }



      public boolean action (Event evt, Object arg)
      {

         boolean bound;

         if (evt.target instanceof Button)
         {
            if (arg.equals("Get Status"))
            {
               if ( (station == null) || (!stName.equals(nameField.getText()) ) )
               {
                   stName = nameField.getText();
                   bound = bindStation(nameField.getText());

                   if (!bound)
                      station = null;
               }

               if (station == null)
                  initStData();
               else
               {
                  try
                  {
                     stationData = station.getStatus();
                  }
                  catch(org.omg.CORBA.SystemException e)
                  {
                     System.err.println(e);
                     e.printStackTrace();
                     System.out.println("Couldn't find station " + stName);
                     station = null;
                     initStData();
                     writeValues();
                     return false;
                  }
               }

               writeValues();
             }
         }

         return true;
      }

}

