package StationModule;

import java.lang.Float;

class StationOptions {
    public boolean rc = false;     // Register Collector?
    public boolean cn = false;     // Collector name provided?
    public boolean sn = false;     // Station name provided?
    public boolean si = false;     // Station id provided?
    public boolean sd = false;     // Station desription provided?
    public boolean un = false;     // Initial units provided?
    public boolean sf = false;     // Simulation factor provided?
    public boolean tp = false;     // Time per simulation unit provided?
    public boolean debug = false;  // Display debug messages?
    
    public String cname = "Collector";              // Collector Name
    public String sname = "StationA";               // Station Name
    public String sid = "A";                        // Station id
    public String sdesc = "Building Component 'A'"; // Station description
    public int    iunits = 5;                       // Initial units
    public float  simfact = (float) 5.0;            // Simulation factor
    public int    tpu = 4;                          // Time per unit
    
    public void usage() {
        System.out.println("Usage: Loser!");
    }
    
    public StationOptions(String args[]) {
        String optVal;  // Value of an option
        
        for (int index=0; index < args.length; index++) {
            if (args[index].startsWith("--")) {
            } else if (args[index].startsWith("-")) {
                if (args[index].length() != 2) {
                    System.out.println("Bad args");
                }
                if (index < args.length-1) {
                    optVal = args[index+1];
                } else {
                    optVal = null;
                }
                
                switch (args[index].charAt(1)) {
                    case 'n':
                        if (optVal == null) { 
                            usage(); 
                        }
                        sn = true;
                        sname = optVal;
                        index++;
                        break;
                        
                    case 'i':
                        if (optVal == null) { 
                            usage(); 
                        }
                        si = true;
                        sid = optVal;
                        index++;
                        break;
                        
                    case 'd':
                        if (optVal == null) { 
                            usage(); 
                        }
                        sd = true;
                        sdesc = optVal;
                        index++;
                        break;
                        
                    case 'u':
                        if (optVal == null) { 
                            usage(); 
                        }
                        un = true;
                        try {
                            iunits = Integer.parseInt(optVal);
                        } catch (NumberFormatException e) {
                            usage();
                        }
                        index++;
                        break;
                        
                    case 't':
                        if (optVal == null) { 
                            usage(); 
                        }
                        tp = true;
                        try {
                            tpu = Integer.parseInt(optVal);
                        } catch (NumberFormatException e) {
                            usage();
                        }
                        index++;
                        break;
                        
                    case 's':
                        if (optVal == null) { 
                            usage(); 
                        }
                        sf = true;
                        simfact = Float.valueOf(optVal).floatValue();
                        index++;
                        break;
                        
                    case 'c':
                        if (optVal == null) { 
                            usage(); 
                        }
                        cn = true;
                        cname = optVal;
                        index++;
                        break;
                        
                    case 'r':
                        rc = true;
                        break;                        
                        
                    case 'D':
                        debug = true;
                        break;
                        
                    default:
                        usage();
                        break;
                }
            }
        }
    }
    
    boolean CheckOpts() {
        return true;
    }
    
};